]> sigrok.org Git - libsigrok.git/blobdiff - strutil.c
Use g_try_malloc/g_free/g_strdup consistently.
[libsigrok.git] / strutil.c
index ef6d9633a28ba84be38df1ebd7d12bb93e2c5068..5e8689e7a17768fc5db21ce5f80e6323edb3b97f 100644 (file)
--- a/strutil.c
+++ b/strutil.c
  * E.g. a value of 3000000 would be converted to "3 MHz", 20000 to "20 kHz".
  *
  * @param samplerate The samplerate in Hz.
* @return A malloc()ed string representation of the samplerate value,
*         or NULL upon errors. The caller is responsible to free() the memory.
  */
-char *sr_samplerate_string(uint64_t samplerate)
+SR_API char *sr_samplerate_string(uint64_t samplerate)
 {
        char *o;
        int r;
 
-       o = malloc(30 + 1); /* Enough for a uint64_t as string + " GHz". */
-       if (!o)
+       /* Allocate enough for a uint64_t as string + " GHz". */
+       if (!(o = g_try_malloc0(30 + 1))) {
+               sr_err("strutil: %s: o malloc failed", __func__);
                return NULL;
+       }
 
        if (samplerate >= SR_GHZ(1))
                r = snprintf(o, 30, "%" PRIu64 " GHz", samplerate / 1000000000);
@@ -53,7 +56,7 @@ char *sr_samplerate_string(uint64_t samplerate)
 
        if (r < 0) {
                /* Something went wrong... */
-               free(o);
+               g_free(o);
                return NULL;
        }
 
@@ -67,17 +70,20 @@ char *sr_samplerate_string(uint64_t samplerate)
  * E.g. a value of 3000000 would be converted to "3 us", 20000 to "50 ms".
  *
  * @param frequency The frequency in Hz.
* @return A malloc()ed string representation of the frequency value,
*         or NULL upon errors. The caller is responsible to free() the memory.
  */
-char *sr_period_string(uint64_t frequency)
+SR_API char *sr_period_string(uint64_t frequency)
 {
        char *o;
        int r;
 
-       o = malloc(30 + 1); /* Enough for a uint64_t as string + " ms". */
-       if (!o)
+       /* Allocate enough for a uint64_t as string + " ms". */
+       if (!(o = g_try_malloc0(30 + 1))) {
+               sr_err("strutil: %s: o malloc failed", __func__);
                return NULL;
+       }
 
        if (frequency >= SR_GHZ(1))
                r = snprintf(o, 30, "%" PRIu64 " ns", frequency / 1000000000);
@@ -90,7 +96,7 @@ char *sr_period_string(uint64_t frequency)
 
        if (r < 0) {
                /* Something went wrong... */
-               free(o);
+               g_free(o);
                return NULL;
        }
 
@@ -104,8 +110,8 @@ char *sr_period_string(uint64_t frequency)
  * @param triggerstring TODO
  * @return TODO
  */
-char **sr_parse_triggerstring(struct sr_device *device,
-                             const char *triggerstring)
+SR_API char **sr_parse_triggerstring(struct sr_device *device,
+                                    const char *triggerstring)
 {
        GSList *l;
        struct sr_probe *probe;
@@ -166,8 +172,7 @@ char **sr_parse_triggerstring(struct sr_device *device,
 
        if (error) {
                for (i = 0; i < max_probes; i++)
-                       if (triggerlist[i])
-                               g_free(triggerlist[i]);
+                       g_free(triggerlist[i]);
                g_free(triggerlist);
                triggerlist = NULL;
        }
@@ -190,7 +195,7 @@ char **sr_parse_triggerstring(struct sr_device *device,
  * @return SR_OK or error code
  *
  */
-int sr_parse_sizestring(const char *sizestring, uint64_t *size)
+SR_API int sr_parse_sizestring(const char *sizestring, uint64_t *size)
 {
        int multiplier, done;
        char *s;
@@ -248,7 +253,7 @@ int sr_parse_sizestring(const char *sizestring, uint64_t *size)
  * TODO: picoseconds?
  * TODO: Allow both lower-case and upper-case.
  */
-uint64_t sr_parse_timestring(const char *timestring)
+SR_API uint64_t sr_parse_timestring(const char *timestring)
 {
        uint64_t time_msec;
        char *s;
@@ -271,15 +276,15 @@ uint64_t sr_parse_timestring(const char *timestring)
        return time_msec;
 }
 
-gboolean sr_parse_boolstring(const char *boolstr)
+SR_API gboolean sr_parse_boolstring(const char *boolstr)
 {
        if (!boolstr)
                return FALSE;
 
-       if (!g_strcasecmp(boolstr, "true") || 
+       if (!g_strcasecmp(boolstr, "true") ||
            !g_strcasecmp(boolstr, "yes") ||
            !g_strcasecmp(boolstr, "on") ||
-           !g_strcasecmp(boolstr, "1")) 
+           !g_strcasecmp(boolstr, "1"))
                return TRUE;
 
        return FALSE;
@@
  *
  * @param samplerate The samplerate in Hz.
- * @return A malloc()ed string representation of the samplerate value,
- *         or NULL upon errors. The caller is responsible to free() the memory.
+ * @return A g_try_malloc()ed string representation of the samplerate value,
+ *         or NULL upon errors. The caller is responsible to g_free() the
+ *         memory.
  */
@@ -67,17 +70,20 @@ char *sr_samplerate_string(uint64_t samplerate)
  *
  * @param frequency The frequency in Hz.
- * @return A malloc()ed string representation of the frequency value,
- *         or NULL upon errors. The caller is responsible to free() the memory.
+ * @return A g_try_malloc()ed string representation of the frequency value,
+ *         or NULL upon errors. The caller is responsible to g_free() the
+ *         memory.
  */